<?php

add_action( 'init',  function(){
    if ( ! function_exists( 'register_block_type' ) ) {
        return;
    }

    wp_register_style(
        'wp-syn-front',
        plugins_url('css/wpsyn.css', __DIR__)
    );
    $style_dependencies = array('wp-syn-front', 'dashicons');

    if(file_exists(get_stylesheet_directory().'/wpsyn.css')){
        wp_register_style(
            'wp-syn-theme',
            get_stylesheet_directory_uri().'/wpsyn.css'
        );
        $style_dependencies[] = 'wp-syn-theme';
    }

    wp_register_style(
        'syn-block',
        plugins_url('css/block-style.css', __DIR__),
        $style_dependencies
    );

    wp_register_script(
        'syn-block',
        plugins_url('js/block-syn.min.js', __DIR__ ),
        [
            'wp-blocks',
            'wp-element',
            'wp-editor',
            'wp-components',
            'wp-i18n',
            'wp-server-side-render'
        ],
        filemtime(plugin_dir_path(__DIR__).'js/block-syn.min.js')
    );

    wp_localize_script( 'syn-block', 'syn_block',
        [
            'date_format'=> get_option('date_format').' '.get_option('time_format'),
            'title'=>__('WP SlideYourNet','wp-slideyournet'),
            'description'=>__('Posts from SlideYourNet', 'wp-slideyournet'),
            'fields'=>array(
                'account' => __("Account", 'wp-slideyournet'),
                'account_desc' => __("Override general account", 'wp-slideyournet'),
                'session' => __("Session slug", 'wp-slideyournet'),
                'token' => __("Token", 'wp-slideyournet'),
                'filters' => __("Filters", 'wp-slideyournet'),
                'filters_desc' => __("Which posts will be displayed", 'wp-slideyournet'),
                'display' => __("Display", 'wp-slideyournet'),
                'display_desc' => __("How posts will be displayed", 'wp-slideyournet'),
                'all' => __("All", 'wp-slideyournet'),
                'display' => __("Display", 'wp-slideyournet'),
                'displayavatar' => _x("Avatar", 'sort order', 'wp-slideyournet'),
                'displaydate' => __("Date", 'wp-slideyournet'),
                'displaymedia' => __("Media", 'wp-slideyournet'),
                'displayusername' => _x("Username", 'block', 'wp-slideyournet'),
                'network' => _x("Network:", 'block', 'wp-slideyournet'),
                'nbrchar' => _x("Number of Characters:", 'block', 'wp-slideyournet'),
                'orderby' => _x("Order by:", 'block', 'wp-slideyournet'),
                'order' => _x("Order:", 'block', 'wp-slideyournet'),
                'perpage' => _x("Per page:", 'block', 'wp-slideyournet'),
                'ref' => _x("Replies:", 'block', 'wp-slideyournet'),
                'search' => _x("Search:", 'block', 'wp-slideyournet'),
                'stylesheet' => _x("Template:", 'block', 'wp-slideyournet'),
                'username' => _x("Username:", 'block', 'wp-slideyournet'),
                'local' => _x("Use Local Storage", 'block', 'wp-slideyournet'),
                'basic' => _x("Basic", 'block', 'wp-slideyournet'),
                'modern' => _x("Modern", 'block', 'wp-slideyournet'),
                'masonry' => _x("Masonry", 'block', 'wp-slideyournet'),
                'none' => _x("None", 'block', 'wp-slideyournet'),
                'theme' => _x("themefolder/wpsyn.css", 'block', 'wp-slideyournet'),
            ),
            'help_message'=>__('Manage settings', 'wp-slideyournet'),
            'help_link'=>add_query_arg(
                array(
                    'page' => 'syn-settings'
                ),
                admin_url('options-general.php')
            ),
            'help_label'=>__('here', 'wp-slideyournet')
        ]
    );

    register_block_type( 'syn/block-syn', array(
        'editor_script' => 'syn-block',
        'editor_style' => 'syn-block',
        'style' => 'syn-block',
        'render_callback' => [wp_syn(), 'shortcode'],
        'attributes' => [
          "session" => [ "type" => "string" ],
          "token" => [ "type" => "string" ],
          "network" => [ "type" => "string" ],
          "local_storage" => [ "type" => "boolean" ],
          "username" => [ "type" => "string" ],
          "search" => [ "type" => "string" ],
          "ref" => [ "type" => "string" ],
          "order_by" => [ "type" => "string" ],
          "order" => [ "type" => "string" ],
          "per_page" => [ "type" => "number" ],
          "display_date" => [ "type" => "boolean" ],
          "display_username" => [ "type" => "boolean" ],
          "display_avatar" => [ "type" => "boolean" ],
          "display_media" => [ "type" => "boolean" ],
          "characters" => [ "type" => "number" ],
          "stylesheet" => [ "type" => "string" ],
        ]
    ) );
} );
